# SocialAD
This is a package developed for a class project.

## Final Project CS107/AC207/CS207
### Group 29
#### Members

1. Tao Tsui
2. Jenny Wang
3. Dashiell Saver-Young
4. Apisada Chulakadabba

[![Build Status](https://travis-ci.com/climate-change-is-real-python-dev/cs107-FinalProject.svg?branch=Milestone_1B)](https://travis-ci.com/climate-change-is-real-python-dev/cs107-FinalProject)

CodeCov Badge
[![codecov](https://codecov.io/gh/climate-change-is-real-python-dev/cs107-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/climate-change-is-real-python-dev/cs107-FinalProject)
